{
  lib,
  config,
  pkgs,
  ...
}:
let
  inherit (lib) mkEnableOption mkIf;

  cfg = config.metacfg.tools.alacritty;
in
{
  options.metacfg.tools.alacritty = {
    enable = mkEnableOption "alacritty";
  };

  config = mkIf cfg.enable {
    environment.systemPackages = with pkgs; [ alacritty ];
    xdg.configFile."alacritty/alacritty.toml".source =
      (pkgs.formats.toml { }).generate "alacritty-config"
        {
          font = {
            normal.family = "JetBrainsMono Nerd Font";
            size = 17;
          };

          # Color theme ported from iTerm 2 Smoooooth
          colors.primary = {
            foreground = "#dbdbdb";
            background = "#14191e";
          };

          colors.cursor = {
            text = "#000000";
            cursor = "#fefffe";
          };

          colors.selection = {
            text = "#000000";
            background = "#b3d7ff";
          };

          colors.normal = {
            black = "#14191e";
            red = "#b43c29";
            green = "#00c200";
            yellow = "#c7c400";
            blue = "#2743c7";
            magenta = "#bf3fbd";
            cyan = "#00c5c7";
            white = "#c7c7c7";
          };

          colors.bright = {
            black = "#676767";
            red = "#dc7974";
            green = "#57e690";
            yellow = "#ece100";
            blue = "#a6aaf1";
            magenta = "#e07de0";
            cyan = "#5ffdff";
            white = "#feffff";
          };
        };
  };
}
